@@ -1,29 +1,30 @@
 from __future__ import annotations
-from uuid import uuid4
+
 import contextlib
-import shutil
-from pathlib import Path
 import json
 import logging
 import os
 import random
 import re
+import shutil
 import time
 from concurrent.futures import Future, ThreadPoolExecutor, as_completed
+from pathlib import Path
 from typing import Any, Callable, Dict, Generator, List, Optional, Set, Tuple
-from github.CheckRun import CheckRun
-from stringcolor import cs
+from uuid import uuid4
 
-from github.Branch import Branch
 import requests
 import shortuuid
-from starlette.datastructures import Headers
 import yaml
 from github import GithubException
+from github.Branch import Branch
+from github.CheckRun import CheckRun
 from github.Commit import Commit
-from github.PullRequest import PullRequest
 from github.GithubException import UnknownObjectException
-from timeout_sampler import TimeoutSampler, TimeoutExpiredError
+from github.PullRequest import PullRequest
+from starlette.datastructures import Headers
+from stringcolor import cs
+from timeout_sampler import TimeoutExpiredError, TimeoutSampler
 
 from webhook_server_container.libs.config import Config
 from webhook_server_container.libs.jira_api import JiraApi
@@ -53,6 +54,8 @@ from webhook_server_container.utils.constants import (
     LGTM_BY_LABEL_PREFIX,
     LGTM_STR,
     NEEDS_REBASE_LABEL_STR,
+    OTHER_MAIN_BRANCH,
+    PRE_COMMIT_STR,
     PYTHON_MODULE_INSTALL_STR,
     QUEUED_STR,
     REACTIONS,
@@ -63,19 +66,17 @@ from webhook_server_container.utils.constants import (
     USER_LABELS_DICT,
     VERIFIED_LABEL_STR,
     WIP_STR,
-    PRE_COMMIT_STR,
-    OTHER_MAIN_BRANCH,
 )
 from webhook_server_container.utils.github_repository_settings import (
     get_repository_github_app_api,
 )
 from webhook_server_container.utils.helpers import (
-    get_api_with_highest_rate_limit,
     extract_key_from_dict,
+    get_api_with_highest_rate_limit,
+    get_apis_and_tokes_from_config,
     get_github_repo_api,
     get_value_from_dicts,
     run_command,
-    get_apis_and_tokes_from_config,
 )
 
 
@@ -305,7 +306,7 @@ Available user actions:
 
         return self.repository_name
 
-    def prepare_log_prefix(self, pull_request: Optional[PullRequest] = None) -> str:
+    def prepare_log_prefix(self, pull_request: PullRequest | None = None) -> str:
         _repository_color = self._get_reposiroty_color_for_log_prefix()
         return (
             f"{_repository_color}[{self.github_event}][{self.x_github_delivery}][PR {pull_request.number}]:"
@@ -788,19 +789,16 @@ stderr: `{_err}`
         pr_tag = repository_full_tag.split(":")[-1]
         registry_info = self.container_repository.split("/")
         registry_url = "" if len(registry_info) < 3 else registry_info[0]
-        base_regctl_command = (
-            "podman run --rm --net host -v regctl-conf:/home/appuser/.regctl/ ghcr.io/regclient/regctl:latest"
-        )
 
-        reg_login_cmd = f"{base_regctl_command} registry login {registry_url} -u {self.container_repository_username} -p {self.container_repository_password}"
+        reg_login_cmd = f"regctl registry login {registry_url} -u {self.container_repository_username} -p {self.container_repository_password}"
         rc, out, err = self.run_podman_command(command=reg_login_cmd)
 
         if rc:
-            tag_ls_cmd = f"{base_regctl_command} tag ls {self.container_repository} --include {pr_tag}"
+            tag_ls_cmd = f"regctl tag ls {self.container_repository} --include {pr_tag}"
             rc, out, err = self.run_podman_command(command=tag_ls_cmd)
 
             if rc and out:
-                tag_del_cmd = f"{base_regctl_command} tag delete {repository_full_tag}"
+                tag_del_cmd = f"regctl tag delete {repository_full_tag}"
 
                 if self.run_podman_command(command=tag_del_cmd)[0]:
                     self.pull_request.create_issue_comment(f"Successfully removed PR tag: {repository_full_tag}.")
@@ -1730,6 +1728,7 @@ stderr: `{_err}`
             reviewers_and_approvers = self.root_reviewers + self.root_approvers
             if self.parent_committer in reviewers_and_approvers:
                 self.jira_assignee = self.jira_user_mapping.get(self.parent_committer)
+                self.add_api_users_to_auto_verified_and_merged_users
                 if not self.jira_assignee:
                     self.logger.debug(
                         f"{self.log_prefix} Jira tracking is disabled for the current pull request. "
