@@ -24,7 +24,6 @@ CHANGED_REQUESTED_BY_LABEL_PREFIX: str = "changes-requested-"
 COMMENTED_BY_LABEL_PREFIX: str = "commented-"
 BRANCH_LABEL_PREFIX: str = "branch-"
 VERIFIED_LABEL_STR: str = "verified"
-APPROVED_LABEL_STR: str = "approved"
 NEEDS_REBASE_LABEL_STR: str = "needs-rebase"
 HAS_CONFLICTS_LABEL_STR: str = "has-conflicts"
 HOLD_LABEL_STR: str = "hold"
@@ -34,6 +33,7 @@ COMMAND_RETEST_STR = "retest"
 COMMAND_CHERRY_PICK_STR = "cherry-pick"
 COMMAND_ASSIGN_REVIEWERS_STR = "assign-reviewers"
 COMMAND_CHECK_CAN_MERGE_STR = "check-can-merge"
+COMMAND_ASSIGN_REVIEWER_STR = "assign-reviewer"
 
 # Gitlab colors require a '#' prefix; e.g: #
 USER_LABELS_DICT: Dict[str, str] = {
